@@ -1,7 +1,7 @@
 """
 pylibftdi - python wrapper for libftdi
 
-Copyright (c) 2010-2011 Ben Bass <benbass@codedstructure.net>
+Copyright (c) 2010-2012 Ben Bass <benbass@codedstructure.net>
 See LICENSE file for details and (absence of) warranty
 
 pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
@@ -14,12 +14,13 @@ if something goes wrong here, it's almost definitely my fault
 rather than a problem with the libftdi library.
 """
 
-__VERSION__ = "0.8.1"
+__VERSION__ = "0.9"
 __AUTHOR__ = "Ben Bass"
 
 
 __ALL__ = ['Driver', 'Device', 'BitBangDevice', 'Bus', 'FtdiError',
-           'ALL_OUTPUTS', 'ALL_INPUTS', 'BB_OUTPUT', 'BB_INPUT']
+           'ALL_OUTPUTS', 'ALL_INPUTS', 'BB_OUTPUT', 'BB_INPUT',
+           'examples', 'tests']
 
 from pylibftdi import _base, driver, util, bitbang
 
@@ -41,6 +42,7 @@ FLUSH_OUTPUT = driver.FLUSH_OUTPUT
 
 # LEGACY SUPPORT
 
+
 class BitBangDriver(bitbang.BitBangDevice):
     def __init__(self, direction=ALL_OUTPUTS):
         import warnings
