@@ -1,7 +1,7 @@
 """
 pylibftdi - python wrapper for libftdi
 
-Copyright (c) 2010-2011 Ben Bass <benbass@codedstructure.net>
+Copyright (c) 2010-2012 Ben Bass <benbass@codedstructure.net>
 See LICENSE file for details and (absence of) warranty
 
 pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
@@ -9,34 +9,41 @@ pylibftdi: http://bitbucket.org/codedstructure/pylibftdi
 """
 
 from pylibftdi.driver import Device, FtdiError
+from ctypes import c_ubyte, byref
 
 ALL_OUTPUTS = 0xFF
 ALL_INPUTS = 0x00
 BB_OUTPUT = 1
 BB_INPUT = 0
 
+
 class BitBangDevice(Device):
     """
     simple subclass to support bit-bang mode
 
-    Only uses async mode at the moment.
+    Internally uses async mode at the moment, but provides a 'sync'
+    flag (defaulting to True) which controls the behaviour of port
+    reading and writing - if set, the FIFOs are ignored (read) or
+    cleared (write) so operations will appear synchronous
 
     Adds two read/write properties to the base class:
      direction: 8 bit input(0)/output(1) direction control.
      port: 8 bit IO port, as defined by direction.
     """
     def __init__(self,
-                 device_id = None,
-                 direction = ALL_OUTPUTS,
-                 lazy_open = False):
+                 device_id=None,
+                 direction=ALL_OUTPUTS,
+                 lazy_open=False,
+                 sync=True):
         # initialise the super-class, but don't open yet. We really want
         # two-part initialisation here - set up all the instance variables
         # here in the super class, then open it after having set more
         # of our own variables.
-        super(BitBangDevice, self).__init__(device_id = device_id,
-                                            mode = 'b',
-                                            lazy_open = True)
+        super(BitBangDevice, self).__init__(device_id=device_id,
+                                            mode='b',
+                                            lazy_open=True)
         self.direction = direction
+        self.sync = sync
         self._last_set_dir = None
         self._latch = 0
         if not lazy_open:
@@ -51,7 +58,6 @@ class BitBangDevice(Device):
             self.direction = self._direction
         return self
 
-
     # direction property - 8 bit value determining whether an IO line
     # is output (if set to 1) or input (set to 0)
     @property
@@ -71,7 +77,6 @@ class BitBangDevice(Device):
             self.ftdi_fn.ftdi_set_bitmode(dir, 0x01)
             self._last_set_dir = dir
 
-
     # port property - 8 bit read/write value
     @property
     def port(self):
@@ -80,10 +85,18 @@ class BitBangDevice(Device):
         lines is persisted in this object for the purposes of reading,
         so read-modify-write operations (e.g. drv.port+=1) are valid.
         """
-        # the coercion to bytearray here is to make this work
-        # transparently between Python2 and Python3 - equivalent
-        # of ord() for Python2, a time-wasting do-nothing on Python3
-        result = bytearray(super(BitBangDevice, self).read(1))[0]
+        if self.sync:
+            pin_byte = c_ubyte()
+            res = self.fdll.ftdi_read_pins(self.ctx, byref(pin_byte))
+            if res != 0:
+                raise FtdiError("Could not read device pins")
+            result = pin_byte.value
+        else:
+            # the coercion to bytearray here is to make this work
+            # transparently between Python2 and Python3 - equivalent
+            # of ord() for Python2, a time-wasting do-nothing on Python3
+            result = bytearray(super(BitBangDevice, self).read(1))[0]
+
         # replace the 'output' bits with current value of _latch -
         # the last written value. This makes read-modify-write
         # operations (e.g. 'drv.port |= 0x10') work as expected
@@ -93,5 +106,6 @@ class BitBangDevice(Device):
     @port.setter
     def port(self, value):
         self._latch = value
+        if self.sync:
+            self.flush_output()
         return super(BitBangDevice, self).write(chr(value))
-
